#
# spec file for package libnftnl
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libnftnl
VCS: https://src.suse.de/SLFO-pool/libnftnl#23892db723f811178cf18905743019975ca115a31832cbfe3c5dbe64582ab287
%define lname	libnftnl11
Version:        1.2.6
Release:        slfo.1.1_1.2
Summary:        Userspace library to access the nftables Netlink interface
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Security
URL:            https://netfilter.org/projects/libnftnl/

#Git-Clone:	git://git.netfilter.org/libnftnl
Source:         http://ftp.netfilter.org/pub/libnftnl/%name-%version.tar.xz
Source2:        http://ftp.netfilter.org/pub/libnftnl/%name-%version.tar.xz.sig
Source9:        %name.keyring
BuildRequires:  xz
BuildRequires:  pkgconfig(libmnl) >= 1.0.4

%description
libnftnl is a userspace library providing a low-level netlink
programming interface (API) to the in-kernel nf_tables subsystem.

%package -n %lname
Summary:        Userspace library to access the nftables Netlink interface
Group:          System/Libraries

%description -n %lname
libnftnl is a userspace library providing a low-level netlink
programming interface (API) to the in-kernel nf_tables subsystem.

%package devel
Summary:        Development files for libnftnl
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libnftnl is a userspace library providing a low-level netlink
programming interface (API) to the in-kernel nf_tables subsystem.

This subpackage contains libraries and header files for developing
applications that want to make use of libnftnl.

%prep
%autosetup -p1

%build
# includedir intentional, cf. bugzilla.opensuse.org/795968
%configure --with-xml-parsing --includedir="%_includedir/%name"
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libnftnl.so.11*

%files devel
%_includedir/%name/
%_libdir/libnftnl.so
%_libdir/pkgconfig/libnftnl.pc
%license COPYING

%changelog
* Tue Jul 11 2023 jengelh@inai.de
- Update to release 1.2.6
  * expr: meta: introduce broute meta expression
* Thu Mar  9 2023 jengelh@inai.de
- Update to release 1.2.5
  * expr: add inner support
* Thu Nov 10 2022 jengelh@inai.de
- Update to release 1.2.4
  * rule, set_elem: remove trailing \n in userdata snprintf
  * libnftnl: Fix res_id byte order
* Tue Aug  9 2022 jengelh@inai.de
- Update to release 1.2.3
  * This release includes a compile time bugfix with clang and
  - D_FORTIFY_SOURCE=2.
* Tue Jun  7 2022 jengelh@inai.de
- Update to release 1.2.2
  * exthdr: tcp option reset support
* Thu Nov 18 2021 jengelh@inai.de
- Update to release 1.2.1
  * expr: add last match time support
  * expr: missing netlink attribute in last expression
* Tue May 25 2021 jengelh@inai.de
- Update to release 1.2.0
  * table: add table owner support
  * expr: socket: add cgroups v2 support
* Fri Jan 15 2021 jengelh@inai.de
- Update to release 1.1.9
  * Improve formatting of registers in bitwise dumps.
* Tue Oct 27 2020 jengelh@inai.de
- Update to release 1.1.8
  * libnftnl: export nftnl_set_elem_fprintf
  * examples: add support for NF_PROTO_INET family
  * table: add userdata support
  * object: add userdata and comment support
  * chain: add userdata and comment support
  * src: add support for chain ID attribute
* Fri Jun  5 2020 jengelh@inai.de
- Update to release 1.1.7
  * udata: add NFTNL_UDATA_SET_DATA_INTERVAL
* Wed Apr  1 2020 jengelh@inai.de
- Update to release 1.1.6
  * add slave device matching
  * support for NFTNL_SET_EXPR
* Mon Dec  2 2019 jengelh@inai.de
- Update to release 1.1.5
  * flowtable: add support for handle attribute
  * obj/ct_timeout: Avoid array overrun in timeout_parse_attr_data()
* Mon Aug 19 2019 jengelh@inai.de
- Update to new upstream release 1.1.4
  * Add ct id support, add ct expectation support,
    add synproxy support.
* Tue May 28 2019 jengelh@inai.de
- Update to new upstream release 1.1.3
  * expr: osf: add version option support
  * udata: add NFTNL_UDATA_* definitions
  * chain: support per chain rules listing
* Tue Nov 13 2018 jengelh@inai.de
- Update to new upstream release 1.1.2
  * This release adds supports for new kernel extensions: tproxy,
    tunneling, xfrm, osf, conntrack timeouts and helpers. This
    release deprecates the nftnl_rule_cmp() interface and the low
    level JSON infrastructure.
- Remove bufferov.diff (obsolete)
* Sat Jun  9 2018 jengelh@inai.de
- Update to new upstream release 1.1.1
  * expr: add map lookups for numgen and hash statements
  * rule: add nftnl_rule_list_insert_at()
  * expr: add connlimit support
  * expr: extend fwd to support address and protocol
* Wed May  2 2018 jengelh@inai.de
- Update to new upstream release 1.1.0
  * Add new API infrastructure to support "flow tables".
* Tue Jan  2 2018 jengelh@inai.de
- Update to new upstream release 1.0.9
  * Mostly bug fixes plus one new nftnl_expr_fprintf() function.
* Fri Oct 13 2017 jengelh@inai.de
- Update to new upstream release 1.0.8
  * ct: add support for zone, helper and eventmask
  * exthdr: tcp option set support
  * rt: tcpmss get support
  * ct: add average bytes per packet counter support
  * exthdr: Add support for exthdr flags
- Add bufferov.diff
- Drop baselibs.conf
* Tue Dec 20 2016 jengelh@inai.de
- Update to new upstream release 1.0.7
  * Support for new kernel expressions: Number generator
    ("numgen"), routing ("rt"), range, inverted set lookups,
    inverted dynamic set updates (i.e. rule mismatch on full
    sets), packet quota, hash, Forward Information Base lookups
    ("fib"), reference to stateful objects, and "notrack".
  * Allow to add userdata to sets.
  * Support for stateful objects, including quota and counter
  * Support for layer 4 pseudoheader fields checksum updates
* Mon May 30 2016 jengelh@inai.de
- Update to new upstream release 1.0.6
  * New TLV infrastructure for user data are in rule, set and
  elements.
  * Support for the new tracing infrastructure.
  * Matching of ct bytes and packets.
  * meta prandom support.
  * Enhancements for the limit expressions.
  * Support for payload mangling.
  * Masquerading port range selection.
* Thu Sep 17 2015 jengelh@inai.de
- Update to new upstream release 1.0.5
  * Resolve improper symbol versioning in the shared library
* Wed Sep 16 2015 jengelh@inai.de
- Update to new upstream release 1.0.4
  * src: add batch abstraction
  * table: add netdev family support
  * chain: add netdev family support
  * set: add support for set timeouts
  * set_elem: add timeout support
  * data: increase maximum possible data size
  * set_elem: support expressions attached to set elements
  * dynset: support expression templates
* Mon Dec 15 2014 jengelh@inai.de
- Update to new upstream release 1.0.3
  * No upstream summary provided
  * Support for new features up to Linux 3.18
* Mon Dec  8 2014 jengelh@inai.de
- Drop %%version from subincludedir, it tends to break recompiles of
  already-built trees on library updates.
* Tue Sep 23 2014 jengelh@inai.de
- Correct pkgconfig-assisted location of headers to match up with
  remaining packages
* Fri Jun 27 2014 jengelh@inai.de
- Update to new upstream release 1.0.2
  * support for Linux 3.15 features, event monitoring, and fixes for
  the XML/JSON infrastructure
* Fri Apr 18 2014 jengelh@inai.de
- Update to new upstream release 1.0.1
  * Memory leak and invalid read fixes
  * Add conntrack label match support
  * meta: Let user specify any combination of sreg/dreg
  * expr: ct: Add support for setting the mark
- Remove 0001-build-resolve-build-failure-involving-linux-netlink..patch,
  0002-build-resolve-compile-error-involving-XT_EXTENSION_M.patch
* Mon Dec 17 2012 jengelh@inai.de
- Initial package (1.0.0+git1) for build.opensuse.org
- Add 0001-build-resolve-build-failure-involving-linux-netlink..patch,
  0002-build-resolve-compile-error-involving-XT_EXTENSION_M.patch
